@@ -10,10 +10,11 @@ __author__     = "Marc-Olivier Buob, Maxime Raynal"
 __maintainer__ = "Marc-Olivier Buob, Maxime Raynal"
 __email__      = "marc-olivier.buob@nokia-bell-labs.com, maxime.raynal@nokia.com"
 __copyright__  = "Copyright (C) 2022, Nokia"
-__license__    = "Nokia"
-__version__    = "0.1.0"
+__license__    = "BSD-3"
+__version__ = '1.0.0'  # Use single quotes for bumpversion (see setup.cfg)
 
 from .boost import *
+from .html import *
 from .language_density import *
 from .multi_grep import *
 from .pattern_automaton import *
